| Title: | Kyoto Prefecture Administrative District Data |
|---|---|
| Description: | This package provides administrative district data of Kyoto Prefecture, Japan. |
| Authors: | Keisuke ANDO [aut, cre] |
| Maintainer: | Keisuke ANDO <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.1.2 |
| Built: | 2026-05-24 05:50:13 UTC |
| Source: | https://github.com/NONONOexe/kyotocities |
Download the Kyoto Prefecture administrative district data provided by the Ministry of Land, Infrastructure, Transport and Tourism.
download_kyoto_district_data(download_dir = getwd())download_kyoto_district_data(download_dir = getwd())
download_dir |
A directory where downloaded file is to saved. |
Path of the downloaded file (invisibly).
## Not run: download_kyoto_district_data("download-dir-path") ## End(Not run)## Not run: download_kyoto_district_data("download-dir-path") ## End(Not run)
The function returns the districts of the specified city name. The search is performed with partial matches.
find_districts(city_name)find_districts(city_name)
city_name |
Part of the city name |
districts of the specified city name
## Not run: fukuchiyama_districts <- find_districts("Fukuchiyama-shi") ## End(Not run)## Not run: fukuchiyama_districts <- find_districts("Fukuchiyama-shi") ## End(Not run)
The function returns the fire station data of the specified city name. The search is performed with partial matches.
find_fire_stations(city_name)find_fire_stations(city_name)
city_name |
Part of the city name |
fire station data of the specified city name
## Not run: fukuchiyama_fire_stations <- find_fire_stations("Fukuchiyama-shi") ## End(Not run)## Not run: fukuchiyama_fire_stations <- find_fire_stations("Fukuchiyama-shi") ## End(Not run)
Information on administrative areas such as cities and wards in Kyoto Prefecture.
kyoto_districtskyoto_districts
Each is a tibble with 36 rows 5 variables:
City names
City codes
City names in japanese
Area of the city (m^2)
Geometry data (polygon or multi-polygon type) of boundaries
kyoto_districtskyoto_districts
Location of fire station in Kyoto Prefecture. The data is generated from OpenStreetMap.
kyoto_fire_stationskyoto_fire_stations
Each is a tibble with 122 rows 2 variables:
Fire station name
Fire station point
kyoto_fire_stationskyoto_fire_stations
Read the Kyoto Prefecture administrative district data.
read_kyoto_district_data(file)read_kyoto_district_data(file)
file |
A file path of data to read. |
Each is a tibble with 69 rows 6 variables:
City names
City codes
City names in japanese
Geometry data (polygon or multi-polygon type) of boundaries
Information on administrative areas such as cities and wards in Kyoto Prefecture.
## Not run: kyoto_districts <- read_kyoto_district_data("N03-20230101_26_GML.zip") ## End(Not run)## Not run: kyoto_districts <- read_kyoto_district_data("N03-20230101_26_GML.zip") ## End(Not run)